@@ -131,7 +131,7 @@ def _get_metrics_str(current_username=""):
     global _metrics_str
 
     username_has_query = False
-    if not current_username.find("?") is -1:
+    if current_username.find("?") != -1:
         username_has_query = True
 
     if _metrics_str is None:
@@ -199,6 +199,9 @@ def _builder(
     if _get(kwargs, 'enable_metrics_collection', True):
         username += _get_metrics_str(username)
 
+    if username == "":
+        username = None
+
     client_bootstrap = _get(kwargs, 'client_bootstrap')
     if client_bootstrap is None:
         client_bootstrap = awscrt.io.ClientBootstrap.get_or_create_static_default()
@@ -427,22 +430,24 @@ def websockets_with_custom_handshake(
                     websocket_proxy_options=websocket_proxy_options,
                     **kwargs)
 
+
 def _add_to_username_parameter(input_string, parameter_value, parameter_pretext):
     """
     Helper function to add parameters to the username in the direct_with_custom_authorizer function
     """
     return_string = input_string
 
-    if not return_string.find("?") is -1:
+    if return_string.find("?") != -1:
         return_string += "&"
     else:
         return_string += "?"
 
-    if not parameter_value.find(parameter_pretext) is -1:
+    if parameter_value.find(parameter_pretext) != -1:
         return return_string + parameter_value
     else:
         return return_string + parameter_pretext + parameter_value
 
+
 def direct_with_custom_authorizer(
         auth_username=None,
         auth_authorizer_name=None,
@@ -482,10 +487,10 @@ def direct_with_custom_authorizer(
     else:
         username_string += auth_username
 
-    if not auth_authorizer_name is None:
+    if auth_authorizer_name is not None:
         username_string = _add_to_username_parameter(
             username_string, auth_authorizer_name, "x-amz-customauthorizer-name=")
-    if not auth_authorizer_signature is None:
+    if auth_authorizer_signature is not None:
         username_string = _add_to_username_parameter(
             username_string, auth_authorizer_signature, "x-amz-customauthorizer-signature=")
 
@@ -507,11 +512,11 @@ def new_default_builder(**kwargs) -> awscrt.mqtt.Connection:
     This builder creates an :class:`awscrt.mqtt.Connection`, without any configuration besides the default TLS context options.
 
     This requires setting the connection details manually by passing all the necessary data
-    in :mod:`common arguments<awsiot.mqtt_connection_builder>` to make a connection
+    in :mod:`common arguments<awsiot.mqtt_connection_builder>` to make a connection.
     """
-    _check_required_kwargs(kwargs)
+    _check_required_kwargs(**kwargs)
     tls_ctx_options = awscrt.io.TlsContextOptions()
 
     return _builder(tls_ctx_options=tls_ctx_options,
                     use_websockets=False,
-                    kwargs=kwargs)
+                    **kwargs)
